SourceFile

Struct SourceFile 

pub struct SourceFile(/* private fields */);
Source file registered as a Salsa input. Setting text on an existing SourceFile is the single write that drives all downstream query invalidation.

Implementations

Source

impl SourceFile

pub fn ingredient(db: &dyn Database) -> &IngredientImpl<Self>

pub fn ingredient_mut( zalsa_mut: &mut Zalsa, ) -> (&mut IngredientImpl<Self>, &mut Runtime)

Source

impl SourceFile

pub fn new<Db_>(db: &Db_, path: Arc<str>, text: Arc<str>) -> Self
where Db_: ?Sized + Database,

pub fn builder(path: Arc<str>, text: Arc<str>) -> <Self as HasBuilder>::Builder

pub fn path<'db, Db_>(self, db: &'db Db_) -> Arc<str>
where Db_: ?Sized + Database,

pub fn text<'db, Db_>(self, db: &'db Db_) -> Arc<str>
where Db_: ?Sized + Database,

pub fn set_path<'db, Db_>( self, db: &'db mut Db_, ) -> impl Setter<FieldTy = Arc<str>> + use<'db, Db_>
where Db_: ?Sized + Database,

pub fn set_text<'db, Db_>( self, db: &'db mut Db_, ) -> impl Setter<FieldTy = Arc<str>> + use<'db, Db_>
where Db_: ?Sized + Database,

pub fn default_debug_fmt(this: Self, f: &mut Formatter<'_>) -> Result
where for<'__trivial_bounds, '__trivial_bounds> Arc<str>: Debug,

Default debug formatting for this struct (may be useful if you define your own Debug impl)