Module parser

Module parser 

Re-exports

pub use docblock::DocblockParser;
pub use docblock::ParsedDocblock;
pub use type_from_hint::type_from_hint;

Modules

docblock
type_from_hint

Structs

FileParser
ParsedFile

Enums

ParseError

Functions

find_preceding_docblock
Scan backwards from offset and return the /** ... */ docblock comment that immediately precedes the token at that position, if any. The docblock must be separated from the declaration only by whitespace.
name_to_string
span_snippet
Extract the source line containing a span.
span_text
Extract the exact source text covered by a span.