Re-exports
pub use docblock::DocblockParser;pub use docblock::ParsedDocblock;pub use type_from_hint::type_from_hint;
Modules
Structs
Enums
Functions
- find_
preceding_ docblock - Scan backwards from
offsetand return the/** ... */docblock comment that immediately precedes the token at that position, if any. The docblock must be separated from the declaration only by whitespace. - name_
to_ string - span_
snippet - Extract the source line containing a span.
- span_
text - Extract the exact source text covered by a span.